Module action

Module action 

Proposed action types for the safety certification kernel.

Structs

SimpleAction
Simple concrete implementation of ProposedAction for testing and basic use.
StateDelta
A single dimension of state change proposed by an action.

Enums

ActionPriority
Priority level of a proposed action.

Traits

ProposedAction
Trait representing an action proposed by an agent for safety certification.