pub struct CertifierConfig {
pub safe_threshold: f64,
pub caution_threshold: f64,
pub block_threshold: f64,
pub warning_margin_threshold: f64,
}Expand description
Configuration for the safety certifier.
Fields
safe_threshold: f64Margin threshold above which the action is in the Safe zone.
caution_threshold: f64Margin threshold above which the action is in the Caution zone.
block_threshold: f64Margin threshold at or below which the action is Blocked.
warning_margin_threshold: f64Margin threshold below which warnings are generated for individual channels.